@@ -2,6 +2,7 @@ package DateTime::Format::Natural::Base;
 
 use strict;
 use warnings;
+no warnings 'uninitialized';
 
 use constant MORNING   => '08';
 use constant AFTERNOON => '14';
@@ -12,9 +13,9 @@ use Date::Calc qw(Add_Delta_Days Days_in_Month
                   Decode_Day_of_Week
                   Nth_Weekday_of_Month_Year);
 
-our $VERSION = '0.9';
+our $VERSION = '0.10';
 
-$SIG{__WARN__} = \&_filter_warnings;
+#$SIG{__WARN__} = \&_filter_warnings;
 
 sub _ago {
     my $self = shift;
@@ -134,7 +135,7 @@ sub _daytime {
              ? $self->{opts}{daytime}{morning}
              : MORNING - $self->{hours_before}));
 
-        undef $self->{hours_before};
+        delete $self->{hours_before};
         $self->_set_modified(1);
     # afternoon
     } elsif ($self->{tokens}->[$self->{index}] =~ $self->{data}->__daytime('afternoon')) {
@@ -144,7 +145,7 @@ sub _daytime {
              ? $self->{opts}{daytime}{afternoon}
              : AFTERNOON - $self->{hours_before}));
 
-        undef $self->{hours_before};
+        delete $self->{hours_before};
         $self->_set_modified(1);
     # evening
     } else {
@@ -154,7 +155,7 @@ sub _daytime {
              ? $self->{opts}{daytime}{evening}
              : EVENING - $self->{hours_before}));
 
-        undef $self->{hours_before};
+        delete $self->{hours_before};
         $self->_set_modified(1);
     }
 
@@ -287,7 +288,7 @@ sub _at {
             }
 
             $self->_set_modified(1);
-            undef $self->{hours_before};
+            delete $self->{hours_before};
         # midnight
         } elsif ($noon_midnight =~ $self->{data}->__at('midnight')) {
             $self->{datetime}->set_hour(0);
@@ -683,12 +684,13 @@ sub _setweekday {
     $self->_set_modified(1);
 }
 
-sub _filter_warnings {
-    if ($_[0] =~ /uninitialized/ &&
-        $_[0] =~ /pattern|string|subtraction/) {
-        return;
-    } else { print $_[0] }
-};
+# XXX defunct - changed signal warning handler globally
+#sub _filter_warnings {
+#    if ($_[0] =~ /uninitialized/ &&
+#        $_[0] =~ /pattern|string|subtraction/) {
+#        return;
+#    } else { print $_[0] }
+#};
 
 1;
 __END__
